==> react-native-dropdown-with-search-and-checkbox-1.0.4.tgz: package/README.md <==

# react-native-dropdown-with-search-and-checkbox

A customizable React Native dropdown component featuring search functionality and checkbox selection (single & multiple). Ideal for creating dynamic, user-friendly dropdowns in your mobile applications.

---

## Features

- 🔍 **Searchable Dropdown**: Easily search through the options.
- ☑️ **Checkbox Selection**: Supports both single and multiple selection.
- 📱 **Modal-based Dropdown**: Beautiful modal dropdown UI.
- 🎨 **Customizable Styles**: Extensive styling options for every aspect of the dropdown.

---

## Installation

Install the package using npm:

```bash
npm install react-native-dropdown-with-search-and-checkbox
```

Additionally, make sure to install the required dependencies:

```bash
npm install react-native-elements react-native-vector-icons
```

For React Native versions below 0.60, link `react-native-vector-icons` manually:

```bash
npx react-native link react-native-vector-icons
```

---

## Usage

To use the dropdown in your React Native app, follow the example below:

### Basic Example

```tsx
import React, { useState } from 'react';
import { View, Text } from 'react-native';
import { DropdownSearch } from 'react-native-dropdown-with-search-and-checkbox';

const App = () => {
  const [selectedItems, setSelectedItems] = useState([]);

  const data = [
    { label: 'Apple', value: 'apple' },
    { label: 'Banana', value: 'banana' },
    { label: 'Mango', value: 'mango' },
  ];

  return (
    <View style={{ flex: 1, justifyContent: 'center' }}>
      <Text>Select Fruits</Text>
      <DropdownSearch
        label="Fruits"
        data={data}
        placeholder="Select fruits"
        multiSelect={true}
        showCheckbox="multiple"
        showFilter={true}
        onSelect={(items) => setSelectedItems(items)}
      />
    </View>
  );
};

export default App;
```


Example 1 Search with Single Select : 
## Screenshot

![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1fce8550593edb9550c95e836152e77da46572b7bd017de7dade0b46a132083141)
![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1f13af598e1d7704f23a0e4e5320201395fd5df2727e781819bde73dbfb71b7dad)
![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1f0515f1c09734035b5bd44ee61ab3366ecd80d658b5c3bebf774bcc244a9c0f21)



---

## Props

| Prop                | Type      | Default       | Description |
|---------------------|-----------|---------------|-------------|
| `data`              | `array`   | `[]`          | List of items to display in the dropdown |
| `onSelect`          | `func`    | required      | Callback function to handle selected items |
| `label`             | `string`  | `''`          | Label displayed above the dropdown |
| `placeholder`       | `string`  | `'Select...'` | Placeholder text displayed when no selection is made |
| `labelKey`          | `string`  | `'label'`     | The key name to access the label in each data item |
| `valueKey`          | `string`  | `'value'`     | The key name to access the value in each data item |
| `multiSelect`       | `bool`    | `false`       | Enables or disables multiple selection |
| `showCheckbox`      | `string`  | `null`        | Set to `'multiple'` to display checkboxes for multiple selection |
| `showFilter`        | `bool`    | `false`       | Shows the filter icon and search input |
| `saveButtonText`    | `string`  | `'Save'`      | Text for the Save button when multiple items are selected |
| `placeholderStyle`  | `object`  | `{}`          | Custom styling for the placeholder text |
| `downArrowStyle`    | `object`  | `{}`          | Custom styling for the dropdown arrow icon |
| `filterIconStyle`   | `object`  | `{}`          | Custom styling for the filter icon |
| `searchInputStyle`  | `object`  | `{}`          | Custom styling for the search input |
| `dropdownButtonStyle` | `object` | `{}`         | Custom styling for the dropdown button |
| `checkboxStyle`     | `object`  | `{}`          | Custom styling for the checkbox |
| `checkboxColor`     | `string`  | `'#007bff'`   | Color for the checkbox |

---

Example 1 Search with Multiple Select : 
## Screenshot

![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1f4016145a16ba45c979e606a70d55a9c632107f31ba0583079c1de39675238da8)
![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1f4c070ca83099bae67c1c9cceff9e379cdca58b2541e9f0dd6ff36bc840bedcb7)
![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1f23a34b7616bf6fcc1fd223c01d5df945cdc1cebb34c225a0fca4a529e12d588b)




## Example with Multiple Selection

```tsx
import React, { useState } from 'react';
import { View, Text } from 'react-native';
import { DropdownSearch } from 'react-native-dropdown-with-search-and-checkbox';

const MultiSelectExample = () => {
  const [selectedItems, setSelectedItems] = useState([]);

  const data = [
    { label: 'Apple', value: 'apple' },
    { label: 'Banana', value: 'banana' },
    { label: 'Mango', value: 'mango' },
  ];

  return (
    <View style={{ flex: 1, justifyContent: 'center' }}>
      <Text>Multi-select Fruits</Text>
      <DropdownSearch
        label="Fruits"
        data={data}
        placeholder="Select fruits"
        multiSelect={true}
        showCheckbox="multiple"
        onSelect={(items) => setSelectedItems(items)}
      />
      <Text>Selected: {selectedItems.map(item => item.label).join(', ')}</Text>
    </View>
  );
};

export default MultiSelectExample;
```

---


Example 3 Search with Multi Select : 
## Screenshot

![Dropdown Screenshot](https://imagekit.io/public/share/dailydev1492/a01cc049a6db58f714077cbdb90e2e8bfb5a05c1f582e4172e0e3c52b284bb7a5a7094425c3329ba93292627cea9ce1fe83cfd4b9803281a5983d9a5bccdb77d74a1081244631449c2daaa21a3b2fb45)



## License

MIT

---

## Author

**Bhumit Dara**

- GitHub: [@bhumitdara](https://github.com/bhumitdara)
- NPM: [@bhumitdara](https://www.npmjs.com/~bhumitdara)

==> react-native-dropdown-with-search-and-checkbox-1.0.5.tgz: package/README.md <==

# react-native-dropdown-with-search-and-checkbox

A customizable React Native dropdown component featuring search functionality and checkbox selection (single & multiple). Ideal for creating dynamic, user-friendly dropdowns in your mobile applications.

---

## Features

- 🔍 **Searchable Dropdown**: Easily search through the options.
- ☑️ **Checkbox Selection**: Supports both single and multiple selection.
- 📱 **Modal-based Dropdown**: Beautiful modal dropdown UI.
- 🎨 **Customizable Styles**: Extensive styling options for every aspect of the dropdown.

---

## Installation

Install the package using npm:

```bash
npm install react-native-dropdown-with-search-and-checkbox
```

Additionally, make sure to install the required dependencies:

```bash
npm install react-native-elements react-native-vector-icons
```

For React Native versions below 0.60, link `react-native-vector-icons` manually:

```bash
npx react-native link react-native-vector-icons
```

---

## Usage

To use the dropdown in your React Native app, follow the example below:

### Basic Example

```tsx
import React, { useState } from 'react';
import { View, Text } from 'react-native';
import { DropdownSearch } from 'react-native-dropdown-with-search-and-checkbox';

const App = () => {
  const [selectedItems, setSelectedItems] = useState([]);

  const data = [
    { label: 'Apple', value: 'apple' },
    { label: 'Banana', value: 'banana' },
    { label: 'Mango', value: 'mango' },
  ];

  return (
    <View style={{ flex: 1, justifyContent: 'center' }}>
      <Text>Select Fruits</Text>
      <DropdownSearch
        label="Fruits"
        data={data}
        placeholder="Select fruits"
        multiSelect={true}
        showCheckbox="multiple"
        showFilter={true}
        onSelect={(items) => setSelectedItems(items)}
      />
    </View>
  );
};

export default App;
```


Example 1 Search with Single Select : 
## Screenshot

![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/01.png)
![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/02.png)
![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/03.png)



---

## Props

| Prop                | Type      | Default       | Description |
|---------------------|-----------|---------------|-------------|
| `data`              | `array`   | `[]`          | List of items to display in the dropdown |
| `onSelect`          | `func`    | required      | Callback function to handle selected items |
| `label`             | `string`  | `''`          | Label displayed above the dropdown |
| `placeholder`       | `string`  | `'Select...'` | Placeholder text displayed when no selection is made |
| `labelKey`          | `string`  | `'label'`     | The key name to access the label in each data item |
| `valueKey`          | `string`  | `'value'`     | The key name to access the value in each data item |
| `multiSelect`       | `bool`    | `false`       | Enables or disables multiple selection |
| `showCheckbox`      | `string`  | `null`        | Set to `'multiple'` to display checkboxes for multiple selection |
| `showFilter`        | `bool`    | `false`       | Shows the filter icon and search input |
| `saveButtonText`    | `string`  | `'Save'`      | Text for the Save button when multiple items are selected |
| `placeholderStyle`  | `object`  | `{}`          | Custom styling for the placeholder text |
| `downArrowStyle`    | `object`  | `{}`          | Custom styling for the dropdown arrow icon |
| `filterIconStyle`   | `object`  | `{}`          | Custom styling for the filter icon |
| `searchInputStyle`  | `object`  | `{}`          | Custom styling for the search input |
| `dropdownButtonStyle` | `object` | `{}`         | Custom styling for the dropdown button |
| `checkboxStyle`     | `object`  | `{}`          | Custom styling for the checkbox |
| `checkboxColor`     | `string`  | `'#007bff'`   | Color for the checkbox |

---

Example 1 Search with Multiple Select : 
## Screenshot

![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/04.png)
![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/05.png)
![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/06.png)




## Example with Multiple Selection

```tsx
import React, { useState } from 'react';
import { View, Text } from 'react-native';
import { DropdownSearch } from 'react-native-dropdown-with-search-and-checkbox';

const MultiSelectExample = () => {
  const [selectedItems, setSelectedItems] = useState([]);

  const data = [
    { label: 'Apple', value: 'apple' },
    { label: 'Banana', value: 'banana' },
    { label: 'Mango', value: 'mango' },
  ];

  return (
    <View style={{ flex: 1, justifyContent: 'center' }}>
      <Text>Multi-select Fruits</Text>
      <DropdownSearch
        label="Fruits"
        data={data}
        placeholder="Select fruits"
        multiSelect={true}
        showCheckbox="multiple"
        onSelect={(items) => setSelectedItems(items)}
      />
      <Text>Selected: {selectedItems.map(item => item.label).join(', ')}</Text>
    </View>
  );
};

export default MultiSelectExample;
```

---


Example 3 Search with Multi Select : 
## Screenshot

![Dropdown Screenshot](https://ik.imagekit.io/dailydev1492/07.png)



## License

MIT

---

## Author

**Bhumit Dara**

- GitHub: [@bhumitdara](https://github.com/bhumitdara)
- NPM: [@bhumitdara](https://www.npmjs.com/~bhumitdara)
